@@ -2,6 +2,12 @@ from os.path import abspath, join, dirname
 import random
 
 
+__title__ = 'names'
+__version__ = '0.2'
+__author__ = 'Trey Hunner'
+__license__ = 'MIT'
+
+
 full_path = lambda filename: abspath(join(dirname(__file__), filename))
 
 
@@ -33,11 +39,3 @@ def get_last_name():
 
 def get_full_name(gender=None):
     return u"%s %s" % (get_first_name(gender), get_last_name())
-
-
-def main():
-    print get_full_name()
-
-
-if __name__ == "__main__":
-    main()
